from PyQt5 import uic
from PyQt5.QtWidgets import QDialog
from qgis.core import QgsFeatureRequest
import os.path
from ..paggf_layers import LoadedLayers
from ..paggf_utils import PAGGFUtils
from ..composer.ComposerValidation import ComposerValidation
from .select_hill import SelectHillDlg

FORM_CLASS, _ = uic.loadUiType(os.path.join(
    os.path.dirname(__file__), 'select_hill.ui'))

def cid_sketch_for_hill(iface):
    dlg = SelectHillDlg()
    if dlg.exec_() == QDialog.Rejected:
        return

    layers = LoadedLayers()
    utils = PAGGFUtils(layers)

    template_path = os.path.join(
        utils.plugin_dir, 'composer/CID_A3_hill_sketch.qpt')

    feature = layers.get_feature('ref', 'hill_districts', dlg.hill_id())

    cv = ComposerValidation(
        feature, template_path, iface, zoom_to_feature=True,
        output_png=True, scale_step=250)

    cv.add_substitutions({
        'LOGO_GIZ_PATH': os.path.join(utils.plugin_dir, 'img/logo_giz.png'),
        'LOGO_EUROPE_PATH': os.path.join(utils.plugin_dir, 'img/logo_europe.png'),
        'LOGO_PAGGF_PATH': os.path.join(utils.plugin_dir, 'img/logo_paggf.png'),
        'LOGO_BURUNDI_PATH':os.path.join(utils.plugin_dir, 'img/Blason_du_Burundi.svg'),
        'NORTH_ARROW_PATH': os.path.join(utils.plugin_dir, 'img/north.png'),
        'province': dlg.province_name(),
        'municipality': dlg.municipality_name(),
        'hill': dlg.hill_name(),
    })

    return cv
