import os
from PyQt5 import uic
from PyQt5.QtWidgets import QDockWidget, QPushButton, QToolButton
from PyQt5.QtCore import QSize
from PyQt5.QtGui import QIcon

FORM_CLASS, _ = uic.loadUiType(os.path.join(
    os.path.dirname(__file__), 'ALL_geom_dockwidget.ui'))


class ALLGeomDW(QDockWidget, FORM_CLASS):
    def __init__(self, pan_trigger_action, parent=None):
        QDockWidget.__init__(self, parent)
        self.setupUi(self)
        self.next_cell_id = 0
        self.col_number = 4 # nombre de colonnes
        self.current_action = None
        self.pan_trigger_action = pan_trigger_action
        self.active = False # True is the DockWidget is displayed
        self.btns = dict()

    def add_action(self, action_name, icon_path, callback, btn_title):
        def exec_callback():
            if self.current_action and self.current_action == action_name:
                self.current_action = None
                self.pan_trigger_action()
                self.btns[action_name].setDown(False)
            else:
                callback()
                self.current_action = action_name
                self.btns[action_name].setDown(True)

        icon = QIcon(icon_path)
        btn = QPushButton(self)
        btn.setIconSize(QSize(32, 32))
        btn.setIcon(icon)
        btn.setToolTip(btn_title)
        btn.clicked.connect(exec_callback)

        col_id = self.next_cell_id // self.col_number
        row_id = self.next_cell_id % self.col_number
        self.next_cell_id += 1

        self.gridLayout.addWidget(btn, col_id, row_id)

        self.btns[action_name] = btn

    def activate_desactivate(self):
        if self.active:
            self.pan_trigger_action()
            self.hide()
        else:
            self.show()

        self.active = not self.active
